Changes
=======

This is a record of all past pybaum releases and what went into them in reverse
chronological order. We follow `semantic versioning <https://semver.org/>`_ and all
releases are available on `Anaconda.org
<https://anaconda.org/OpenSourceEconomics/pybaum>`_.


0.1.x - 2022-xx-xx
------------------

- :gh:`2` replaces the pre-commit pipeline step with pre-commit.ci.
- :gh:`11` implement :func:`pybaum.tree_util.tree_yield` and
  :func:`pybaum.tree_util.tree_just_yield`.
- :gh:`10` adds default arguments to ``tree_just_flatten``.
- :gh:`12` adds a section about the API to the docs.
- :gh:`13` extends the readme.


0.1.0 - 2022-01-28
------------------

- :gh:`1` releases the initial version of pybaum.
